@@ -15,7 +15,7 @@ from django.utils.timezone import now
 # Django bits
 from django.conf import settings
 from django.core.management import call_command
-from django.test import TestCase, override_settings
+from django.test import TestCase, override_settings, TransactionTestCase
 from django.core.management.base import CommandError
 
 # Models
@@ -24,7 +24,7 @@ from calaccess_raw.models import RawDataVersion
 from calaccess_processed.models import ProcessedDataVersion
 from calaccess_scraped.models import Candidate as ScrapedCandidate
 from calaccess_scraped.models import Proposition as ScrapedProposition
-from opencivicdata.core.models import Person
+# from opencivicdata.core.models import Person
 from opencivicdata.elections.models import (
     BallotMeasureContest,
     Candidacy,
@@ -47,7 +47,7 @@ class NoProcessedDataTest(TestCase):
 @override_settings(CALACCESS_DATA_DIR=os.path.join(settings.BASE_DIR, 'test-data'))
 @override_settings(MEDIA_ROOT=os.path.join(settings.BASE_DIR, 'test-data', ".media"))
 @override_settings(CALACCESS_STORE_ARCHIVE=True)
-class ProcessedDataTest(TestCase):
+class ProcessedDataTest(TransactionTestCase):
     """
     Run and test management commands.
     """
@@ -63,12 +63,10 @@ class ProcessedDataTest(TestCase):
 
     @classmethod
     @requests_mock.Mocker()
-    def setUpClass(cls, m):
+    def setUp(cls, m):
         """
         Load data for other tests.
         """
-        super(ProcessedDataTest, cls).setUpClass()
-
         # fake a previous raw data download
         download_dir = os.path.join(settings.CALACCESS_DATA_DIR, 'download')
         os.path.exists(download_dir) or os.mkdir(download_dir)
@@ -108,13 +106,7 @@ class ProcessedDataTest(TestCase):
         call_command("updatecalaccessrawdata", verbosity=3, noinput=True)
         call_command("processcalaccessdata", verbosity=3)
 
-    def runTest(self):
-        """
-        Added to allow calling test_ methods on instance of this class in py2.
-        """
-        pass
-
-    def test_scraped_propositions(self):
+    def test_everything(self):
         """
         Test the scraped propostions loaded into the database.
         """
@@ -125,7 +117,7 @@ class ProcessedDataTest(TestCase):
             BallotMeasureContest.objects.count(),
         )
 
-    def test_correction(self):
+#    def test_correction(self):
         """
         Test that we can retrieve a correction directly.
         """
@@ -138,7 +130,7 @@ class ProcessedDataTest(TestCase):
         )
         self.assertEqual(correx.name, "REPUBLICAN")
 
-    def test_correction_assignment_by_proxy(self):
+#    def test_correction_assignment_by_proxy(self):
         """
         Test that a correction is properly being applied when parties are retrieved.
         """
@@ -146,14 +138,14 @@ class ProcessedDataTest(TestCase):
         obj = ScrapedCandidateProxy.objects.get(name='WINSTON, ALMA MARIE')
         self.assertEqual(obj.get_party().name, 'REPUBLICAN')
 
-    def test_processed_version_completed(self):
+#    def test_processed_version_completed(self):
         """
         Test that the processed version was completed.
         """
         processed_version = ProcessedDataVersion.objects.latest('process_start_datetime')
         self.assertTrue(processed_version.update_completed)
 
-    def test_flat_zip_archived(self):
+#    def test_flat_zip_archived(self):
         """
         Confirm that a flat zip was archived.
         """
@@ -161,7 +153,7 @@ class ProcessedDataTest(TestCase):
         has_flat_zip = processed_version.zips.filter(zip_archive__icontains='flat').exists()
         self.assertTrue(has_flat_zip)
 
-    def test_relational_zip_archived(self):
+#    def test_relational_zip_archived(self):
         """
         Confirm that a relational zip was archived.
         """
@@ -169,7 +161,7 @@ class ProcessedDataTest(TestCase):
         has_relational_zip = processed_version.zips.filter(zip_archive__icontains='relational').exists()
         self.assertTrue(has_relational_zip)
 
-    def test_zip_sizes(self):
+#    def test_zip_sizes(self):
         """
         Confirm that each archived zip's size is the same as the actual file size.
         """
@@ -177,7 +169,7 @@ class ProcessedDataTest(TestCase):
         for z in processed_version.zips.all():
             self.assertEqual(z.zip_size, os.path.getsize(z.zip_archive.path))
 
-    def test_processed_file_finished(self):
+#    def test_processed_file_finished(self):
         """
         Test that each processed file was marked finished.
         """
@@ -185,7 +177,7 @@ class ProcessedDataTest(TestCase):
         for df in processed_version.files.all():
             self.assertTrue(df.process_finish_datetime)
 
-    def test_processed_file_archived(self):
+#    def test_processed_file_archived(self):
         """
         Test that each processed file was archived.
         """
@@ -193,7 +185,7 @@ class ProcessedDataTest(TestCase):
         for df in processed_version.files.all():
             self.assertTrue(df.file_archive)
 
-    def test_processed_file_size(self):
+#    def test_processed_file_size(self):
         """
         Test that each processed file_size is the same as file's size.
         """
@@ -201,7 +193,7 @@ class ProcessedDataTest(TestCase):
         for df in processed_version.files.all():
             self.assertEqual(df.file_size, os.path.getsize(df.file_archive.path))
 
-    def test_processed_file_records_count(self):
+#    def test_processed_file_records_count(self):
         """
         Test that each processed records_count is the same as rows in file.
         """
@@ -212,7 +204,7 @@ class ProcessedDataTest(TestCase):
             df.file_archive.close()
             self.assertEqual(df.records_count, row_count)
 
-    def test_flat_file_row_counts(self):
+#    def test_flat_file_row_counts(self):
         """
         Test that count of rows in flat files is same as row count in base model.
         """
@@ -237,7 +229,7 @@ class ProcessedDataTest(TestCase):
 
             self.assertEqual(flat_row_count, base_row_count)
 
-    def test_scraped_candidates(self):
+#    def test_scraped_candidates(self):
         """
         Test the scraped candidates loaded into the database.
         """
@@ -365,21 +357,21 @@ class ProcessedDataTest(TestCase):
                     ),
                 )
 
-        # For each Person...
-        for person in Person.objects.all():
-            # Confirm name is same as most recent candidate_name
-            latest_candidate_name = person.candidacies.latest(
-                'contest__election__date'
-            ).candidate_name
+#        # For each Person...
+#        for person in Person.objects.all():
+#            # Confirm name is same as most recent candidate_name
+#            latest_candidate_name = person.candidacies.latest(
+#                'contest__election__date'
+#            ).candidate_name
 
-            self.assertEqual(
-                person.name,
-                latest_candidate_name,
-                msg='Person.name "{0}" doesn\'t match latest candidate_name "{1}!'.format(
-                    person.name,
-                    latest_candidate_name,
-                )
-            )
+#            self.assertEqual(
+#                person.name,
+#                latest_candidate_name,
+#                msg='Person.name "{0}" doesn\'t match latest candidate_name "{1}!'.format(
+#                    person.name,
+#                    latest_candidate_name,
+#                )
+#            )
 
     # def test_form460_filings_count(self):
     #     """
